@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: A weighted graph implementation
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use warnings;
 use strict;
@@ -15,14 +15,6 @@ use Readonly;
 Readonly my $WEIGHT => 'weight';
 
 
-sub new {
-    my $class = shift;
-    my $self = $class->SUPER::new();
-    bless $self, $class;
-    return $self;
-}
-
-
 sub populate {
     my ($self, $data, $attr) = @_;
 
@@ -195,7 +187,7 @@ Graph::Easy::Weighted - A weighted graph implementation
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
